# Contributing

By participating in this project, you agree to abide by the [code of conduct].

[code of conduct]: https://github.com/usablica/intro.js/blob/master/CODE_OF_CONDUCT.md

## Best Practices

Before you post any issue or pull request, search [the issues][issues] and [the pull requests][pulls] to see if it has already been addressed. 

[issues]: https://github.com/usablica/intro.js/issues
[pulls]: https://github.com/usablica/intro.js/pulls

Here are some best practices that will help us accept/address pull requests and issues:

* Outline one, **and only one**, specific problem/feature that you are trying to address.
* Write a **good title** that summarizes the specific problem.
* Introduce the problem before you write any code.
* **Help us reproduce the problem** if applicable with a [jsfiddle][jsfiddle]/[codepen][codepen] showcasing the need for a solution.

[jsfiddle]: https://jsfiddle.net/
[codepen]: https://codepen.io/

## Pull Requests

Fork, then clone the repo:

    git clone git@github.com:your-username/intro.js.git

Make your changes and push to your fork and [submit a pull request][pr].

[pr]: https://github.com/usablica/intro.js/compare

At this point you're waiting on us. We may suggest some changes or improvements or alternatives.